# flake8: noqa
from __future__ import unicode_literals

from .youtube import (
    YoutubeIE,
    YoutubeFavouritesIE,
    YoutubeHistoryIE,
    YoutubeTabIE,
    YoutubePlaylistIE,
    YoutubeRecommendedIE,
    YoutubeSearchDateIE,
    YoutubeSearchIE,
    #YoutubeSearchURLIE,
    YoutubeSubscriptionsIE,
    YoutubeTruncatedIDIE,
    YoutubeTruncatedURLIE,
    YoutubeYtBeIE,
    YoutubeYtUserIE,
    YoutubeWatchLaterIE,
)

from .commonmistakes import CommonMistakesIE, UnicodeBOMIE
from .commonprotocols import (
    MmsIE,
    RtmpIE,
)


from setuptools import setup,find_packages

setup(
    packages=find_packages(),
    name = "modified_pafy",
    author = "NA",
    description = "NA",
    install_requires = [],
    version = "1.0.0"
)